pilas.escena.escena_base.Base

Package pilas :: Package escena :: Module escena_base :: Class Base |
[hide private]
[frames] | no frames]

# Class Base

source code

    object --+
             |
            Base

Known Subclasses:
  - demos.piezas.Piezas
  - , escena_normal.Aviso
  - , escena_normal.Normal

Escena base abstracta de la que deben heredar el resto de escenas.

    >>> class MiEscena(Base):
    >>>
    >>>    def __init__(self):
    >>>        Base.__init__(self)
    >>>
    >>>    def iniciar(self):
    >>>        fondo = pilas.fondos.Color(pilas.colores.grisclaro)

Si heredas de esta clase DEBES redefinir el método "iniciar". Como se muestra en el ejemplo anterior.

Instance Methods | [hide private]
__init__(self) x.__init__(...) initializes x; see help(type(x)) for signature | source code
_actualizar_eventos(self) | source code
_actualizar_fisica(self) | source code
_limpiar(self) | source code
_pausar_fisica(self) | source code
_reanudar_fisica(self) | source code
iniciar(self) Este método debe ser reimplementado en todas las clases que hereden de ella. | source code
pausar(self) Este método es llamado por el gestor de escenas cuando se ::almacena:: una escena para llamar a otra nueva. | source code
reanudar(self) Este método es llamado por el gestor de escenas cuando se ::recupera:: una escena que habia sido almacenada anteriormente. | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)

### iniciar(self) | source code
Este método debe ser reimplementado en todas las clases que hereden de ella.
    >>>    def iniciar(self):
    >>>        fondo = pilas.fondos.Color(pilas.colores.grisclaro)

### pausar(self) | source code
Este método es llamado por el gestor de escenas cuando se ::almacena:: una escena para llamar a otra nueva.
    >>> pilas.almacenar_escena(EscenaDeOpciones())
Al efectuar esta instrucción el gestor llamará primero a nuestro método ::pausar:: antes de cambiar a la escena que le hemos indicado.

### reanudar(self) | source code
Este método es llamado por el gestor de escenas cuando se ::recupera:: una escena que habia sido almacenada anteriormente.
    >>> pilas.recuperar_escena()
Al efectuar esta instrucción el gestor llamará primero a nuestro método ::reanudar:: antes de cambiar a la escena que habiamos almacenado.